summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorShane Kerr <shane@isc.org>2007-01-29 10:41:02 +0000
committerShane Kerr <shane@isc.org>2007-01-29 10:41:02 +0000
commit6edf03c615697adb7caf5a20eabaa2c53a1bd30e (patch)
treec831bc8cb367526b4cf7b4ceb87a512477e5a5f5
parente2a02c6dcacc8467c744a47566c654d27d7c4af1 (diff)
downloadisc-dhcp-6edf03c615697adb7caf5a20eabaa2c53a1bd30e.tar.gz
Spelling fixes. See RT ticket 16513 for details.
-rw-r--r--RELNOTES2
-rw-r--r--client/clparse.c4
-rw-r--r--common/options.c4
-rw-r--r--common/parse.c38
-rw-r--r--common/print.c4
-rw-r--r--common/tables.c8
-rw-r--r--common/tree.c14
-rw-r--r--dhcpctl/omshell.c4
-rw-r--r--doc/ja_JP.eucJP/dhcp-eval.54
-rw-r--r--includes/cf/linux.h2
-rw-r--r--includes/cf/sample.h4
-rw-r--r--includes/dhcpd.h2
-rw-r--r--includes/failover.h2
-rw-r--r--includes/tree.h2
-rw-r--r--server/confpars.c4
-rw-r--r--server/failover.c4
16 files changed, 52 insertions, 50 deletions
diff --git a/RELNOTES b/RELNOTES
index 4450c359..27806172 100644
--- a/RELNOTES
+++ b/RELNOTES
@@ -85,6 +85,8 @@ and for prodding me into improving it.
incorrectly indicating 'up' state when any flags were set, rather than
specifically the INTERFACE_REQUESTED flag.
+- Spelling fixes.
+
Changes since 3.0.5rc2
- Failover servers try harder to retransmit binding updates upon entering
diff --git a/client/clparse.c b/client/clparse.c
index 22f21fd8..8fe02386 100644
--- a/client/clparse.c
+++ b/client/clparse.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: clparse.c,v 1.62.2.12 2006/02/22 22:43:27 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: clparse.c,v 1.62.2.13 2007/01/29 10:41:01 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -288,7 +288,7 @@ void parse_client_statement (cfile, ip, config)
return;
/* REQUIRE can either start a policy statement or a
- comma-seperated list of names of required options. */
+ comma-separated list of names of required options. */
case REQUIRE:
next_token (&val, (unsigned *)0, cfile);
token = peek_token (&val, (unsigned *)0, cfile);
diff --git a/common/options.c b/common/options.c
index 49e8c2e2..c11df0aa 100644
--- a/common/options.c
+++ b/common/options.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: options.c,v 1.85.2.34 2006/02/22 22:43:27 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: options.c,v 1.85.2.35 2007/01/29 10:41:01 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#define DHCP_OPTION_DATA
@@ -441,7 +441,7 @@ int fqdn_universe_decode (struct option_state *options,
}
/* cons options into a big buffer, and then split them out into the
- three seperate buffers if needed. This allows us to cons up a set
+ three separate buffers if needed. This allows us to cons up a set
of vendor options using the same routine. */
int cons_options (inpacket, outpacket, lease, client_state,
diff --git a/common/print.c b/common/print.c
index c1f9d0f7..628ef6e1 100644
--- a/common/print.c
+++ b/common/print.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: print.c,v 1.53.2.14 2006/02/22 22:43:27 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: print.c,v 1.53.2.15 2007/01/29 10:41:01 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -891,7 +891,7 @@ static unsigned print_subexpression (expr, buf, len)
rv += print_subexpression (expr -> data.b2a.width,
buf + rv, len - rv - 3);
buf [rv++] = ' ';
- rv += print_subexpression (expr -> data.b2a.seperator,
+ rv += print_subexpression (expr -> data.b2a.separator,
buf + rv, len - rv - 2);
buf [rv++] = ' ';
rv += print_subexpression (expr -> data.b2a.buffer,
diff --git a/common/tables.c b/common/tables.c
index aff1513a..2458e9b4 100644
--- a/common/tables.c
+++ b/common/tables.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: tables.c,v 1.51.2.14 2006/02/22 22:43:27 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: tables.c,v 1.51.2.15 2007/01/29 10:41:01 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -69,7 +69,7 @@ HASH_FUNCTIONS (option, const char *, struct option, option_hash_t, 0, 0)
F - implicit flag - the presence of the option indicates that the
flag is true.
o - the preceding value is optional.
- E - encapsulation, string or colon-seperated hex list (the latter
+ E - encapsulation, string or colon-separated hex list (the latter
two for parsing). E is followed by a text string containing
the name of the option space to encapsulate, followed by a '.'.
If the E is immediately followed by '.', the applicable vendor
@@ -81,9 +81,9 @@ HASH_FUNCTIONS (option, const char *, struct option, option_hash_t, 0, 0)
thing in the option.
X - either an ASCII string or binary data. On output, the string is
scanned to see if it's printable ASCII and, if so, output as a
- quoted string. If not, it's output as colon-seperated hex. On
+ quoted string. If not, it's output as colon-separated hex. On
input, the option can be specified either as a quoted string or as
- a colon-seperated hex list.
+ a colon-separated hex list.
N - enumeration. N is followed by a text string containing
the name of the set of enumeration values to parse or emit,
followed by a '.'. The width of the data is specified in the
diff --git a/dhcpctl/omshell.c b/dhcpctl/omshell.c
index a762eb4e..76e168ef 100644
--- a/dhcpctl/omshell.c
+++ b/dhcpctl/omshell.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: omshell.c,v 1.7.2.18 2005/10/27 15:56:26 dhankins Exp $ Copyright (c) 2004-2005 Internet Systems Consortium. All rights reserved.\n";
+"$Id: omshell.c,v 1.7.2.19 2007/01/29 10:41:02 shane Exp $ Copyright (c) 2004-2005 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include <time.h>
@@ -473,7 +473,7 @@ int main (int argc, char **argv, char **envp)
case NUMBER:
strcpy (buf, val);
token = peek_token (&val, (unsigned *)0, cfile);
- /* Colon-seperated hex list? */
+ /* Colon-separated hex list? */
if (token == COLON)
goto cshl;
else if (token == DOT) {
diff --git a/doc/ja_JP.eucJP/dhcp-eval.5 b/doc/ja_JP.eucJP/dhcp-eval.5
index 62ad12a2..5b317ece 100644
--- a/doc/ja_JP.eucJP/dhcp-eval.5
+++ b/doc/ja_JP.eucJP/dhcp-eval.5
@@ -1,4 +1,4 @@
-.\" $Id: dhcp-eval.5,v 1.1.2.2 2004/06/10 17:59:27 dhankins Exp $
+.\" $Id: dhcp-eval.5,v 1.1.2.3 2007/01/29 10:41:02 shane Exp $
.\"
.\" Copyright (c) 2004 by Internet Systems Consortium, Inc. ("ISC")
.\" Copyright (c) 1996-2003 by Internet Software Consortium
@@ -250,7 +250,7 @@ FDDI (8) が含まれます。
.\" horikawa@jp.FreeBSD.org 2002/05/01
.RE
.PP
-.I colon-seperated hexadecimal list
+.I colon-separated hexadecimal list
.PP
.RS 0.25i
コロンで区切られた 16 進数のオクテット値のリストを、
diff --git a/includes/cf/linux.h b/includes/cf/linux.h
index 1028a9ca..ad2c9790 100644
--- a/includes/cf/linux.h
+++ b/includes/cf/linux.h
@@ -79,7 +79,7 @@ extern int h_errno;
in /var/state/misc - indeed, given that there's only one lease file, it
would probably be better. However, I have some ideas for optimizing
the lease database that may result in a _lot_ of smaller files being
- created, so in that context it makes more sense to have a seperate
+ created, so in that context it makes more sense to have a separate
directory. */
#ifndef _PATH_DHCPD_DB
diff --git a/includes/cf/sample.h b/includes/cf/sample.h
index 0f793184..deea3ec4 100644
--- a/includes/cf/sample.h
+++ b/includes/cf/sample.h
@@ -256,13 +256,13 @@ char *strerror PROTO ((int));
/* #define HAVE_SA_LEN */
-/* Every operating system has its own way of seperating lines in a
+/* Every operating system has its own way of separating lines in a
sequential text file. Most modern systems use a single character,
either an ASCII Newline (10) or an ASCII Carriage Return (13).
The most notable exception is MS-DOS (and consequently, Windows),
which uses an ASCII Carriage Return followed by a Newline to
- seperate each line. Fortunately, MS-DOS C compiler libraries
+ separate each line. Fortunately, MS-DOS C compiler libraries
typically hide this from the programmer, returning just a Newline.
Define EOL to be whatever getc() returns for a newline. */
diff --git a/includes/dhcpd.h b/includes/dhcpd.h
index af1e0b95..180f2705 100644
--- a/includes/dhcpd.h
+++ b/includes/dhcpd.h
@@ -173,7 +173,7 @@ struct option_tag {
/* An agent option structure. We need a special structure for the
Relay Agent Information option because if more than one appears in
- a message, we have to keep them seperate. */
+ a message, we have to keep them separate. */
struct agent_options {
struct agent_options *next;
diff --git a/includes/failover.h b/includes/failover.h
index f4ff7e9e..e1356b43 100644
--- a/includes/failover.h
+++ b/includes/failover.h
@@ -236,7 +236,7 @@ enum failover_state {
/* Service states are simplifications of failover states, particularly
useful because the startup state isn't actually implementable as a
- seperate failover state without maintaining a state stack. */
+ separate failover state without maintaining a state stack. */
enum service_state {
unknown_service_state,
diff --git a/includes/tree.h b/includes/tree.h
index 64f43977..6ba69877 100644
--- a/includes/tree.h
+++ b/includes/tree.h
@@ -233,7 +233,7 @@ struct expression {
struct {
struct expression *base;
struct expression *width;
- struct expression *seperator;
+ struct expression *separator;
struct expression *buffer;
} b2a;
struct {
diff --git a/server/confpars.c b/server/confpars.c
index cb081037..2f556559 100644
--- a/server/confpars.c
+++ b/server/confpars.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: confpars.c,v 1.143.2.32 2006/07/20 16:02:52 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: confpars.c,v 1.143.2.33 2007/01/29 10:41:02 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -2641,7 +2641,7 @@ int parse_lease_declaration (struct lease **lp, struct parse *cfile)
}
break;
- /* Colon-seperated hexadecimal octets... */
+ /* Colon-separated hexadecimal octets... */
case UID:
seenbit = 8;
token = peek_token (&val, (unsigned *)0, cfile);
diff --git a/server/failover.c b/server/failover.c
index d68f2d6a..c844cf16 100644
--- a/server/failover.c
+++ b/server/failover.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: failover.c,v 1.53.2.46 2006/09/22 16:29:44 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: failover.c,v 1.53.2.47 2007/01/29 10:41:02 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -158,7 +158,7 @@ isc_result_t find_failover_peer (peer, name, file, line)
each failover partner declaration in the dhcpd.conf file, primary
or secondary, there is a failover_state object. For any primary or
secondary state object that has a connection to its peer, there is
- also a failover_link object, which has its own input state seperate
+ also a failover_link object, which has its own input state separate
from the failover protocol state for managing the actual bytes
coming in off the wire. Finally, there will be one listener object
for every distinct port number associated with a secondary
diff --git a/common/parse.c b/common/parse.c
index 72636da9..207e84fe 100644
--- a/common/parse.c
+++ b/common/parse.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: parse.c,v 1.104.2.27 2006/02/22 22:43:27 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: parse.c,v 1.104.2.28 2007/01/29 10:41:01 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -322,7 +322,7 @@ int parse_ip_addr (cfile, addr)
}
/*
- * hardware-parameter :== HARDWARE hardware-type colon-seperated-hex-list SEMI
+ * hardware-parameter :== HARDWARE hardware-type colon-separated-hex-list SEMI
* hardware-type :== ETHERNET | TOKEN_RING | FDDI
*/
@@ -421,18 +421,18 @@ void parse_lease_time (cfile, timep)
}
/* No BNF for numeric aggregates - that's defined by the caller. What
- this function does is to parse a sequence of numbers seperated by
- the token specified in seperator. If max is zero, any number of
+ this function does is to parse a sequence of numbers separated by
+ the token specified in separator. If max is zero, any number of
numbers will be parsed; otherwise, exactly max numbers are
expected. Base and size tell us how to internalize the numbers
once they've been tokenized. */
unsigned char *parse_numeric_aggregate (cfile, buf,
- max, seperator, base, size)
+ max, separator, base, size)
struct parse *cfile;
unsigned char *buf;
unsigned *max;
- int seperator;
+ int separator;
int base;
unsigned size;
{
@@ -453,7 +453,7 @@ unsigned char *parse_numeric_aggregate (cfile, buf,
do {
if (count) {
token = peek_token (&val, (unsigned *)0, cfile);
- if (token != seperator) {
+ if (token != separator) {
if (!*max)
break;
if (token != RBRACE && token != LBRACE)
@@ -691,11 +691,11 @@ TIME parse_date (cfile)
if (year > 1900)
year -= 1900;
/* Slash seperating year from month... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
parse_warn (cfile,
- "expected slash seperating year from month.");
+ "expected slash separating year from month.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -711,11 +711,11 @@ TIME parse_date (cfile)
}
mon = atoi (val) - 1;
/* Slash seperating month from day... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
parse_warn (cfile,
- "expected slash seperating month from day.");
+ "expected slash separating month from day.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -741,11 +741,11 @@ TIME parse_date (cfile)
}
hour = atoi (val);
/* Colon seperating hour from minute... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
parse_warn (cfile,
- "expected colon seperating hour from minute.");
+ "expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -761,11 +761,11 @@ TIME parse_date (cfile)
}
min = atoi (val);
/* Colon seperating minute from second... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
parse_warn (cfile,
- "expected colon seperating hour from minute.");
+ "expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -1406,8 +1406,8 @@ int parse_base64 (data, cfile)
/*
- * colon-seperated-hex-list :== NUMBER |
- * NUMBER COLON colon-seperated-hex-list
+ * colon-separated-hex-list :== NUMBER |
+ * NUMBER COLON colon-separated-hex-list
*/
int parse_cshl (data, cfile)
@@ -2692,7 +2692,7 @@ int parse_boolean_expression (expr, cfile, lose)
* PACKET LPAREN numeric-expression COMMA
* numeric-expression RPAREN |
* STRING |
- * colon_seperated_hex_list
+ * colon_separated_hex_list
*/
int parse_data_expression (expr, cfile, lose)
@@ -3070,7 +3070,7 @@ int parse_non_binary (expr, cfile, lose, context)
if (token != COMMA)
goto nocomma;
- if (!parse_data_expression (&(*expr) -> data.b2a.seperator,
+ if (!parse_data_expression (&(*expr) -> data.b2a.separator,
cfile, lose))
goto nodata;
@@ -691,11 +691,11 @@ TIME parse_date (cfile)
if (year > 1900)
year -= 1900;
- /* Slash seperating year from month... */
+ /* Slash separating year from month... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
@@ -711,11 +711,11 @@ TIME parse_date (cfile)
}
mon = atoi (val) - 1;
- /* Slash seperating month from day... */
+ /* Slash separating month from day... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
@@ -741,11 +741,11 @@ TIME parse_date (cfile)
}
hour = atoi (val);
- /* Colon seperating hour from minute... */
+ /* Colon separating hour from minute... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
@@ -761,11 +761,11 @@ TIME parse_date (cfile)
}
min = atoi (val);
- /* Colon seperating minute from second... */
+ /* Colon separating minute from second... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
diff --git a/common/tree.c b/common/tree.c
index 16003f37..822a6ed8 100644
--- a/common/tree.c
+++ b/common/tree.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: tree.c,v 1.101.2.16 2006/11/06 18:24:57 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: tree.c,v 1.101.2.17 2007/01/29 10:41:02 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -796,7 +796,7 @@ int evaluate_dns_expression (result, packet, lease, client_state, in_options,
ASCII string both look like data expressions, but
for A records, we want an ASCII string, not a
binary IP address. Do I need to turn binary IP
- addresses into a seperate type? */
+ addresses into a separate type? */
return (r0 && r1 &&
(r2 || expr -> op != expr_ns_add) && *result);
@@ -1694,12 +1694,12 @@ int evaluate_data_expression (result, packet, lease, client_state,
scope,
expr -> data.b2a.width);
/* Evaluate the seperator string. */
memset (&data, 0, sizeof data);
s2 = evaluate_data_expression (&data, packet, lease,
client_state,
in_options, cfg_options, scope,
- expr -> data.b2a.seperator,
+ expr -> data.b2a.separator,
MDL);
/* Evaluate the data to be converted. */
@@ -2849,8 +2849,8 @@ void expression_dereference (eptr, file, line)
if (expr -> data.b2a.width)
expression_dereference (&expr -> data.b2a.width,
file, line);
- if (expr -> data.b2a.seperator)
- expression_dereference (&expr -> data.b2a.seperator,
+ if (expr -> data.b2a.separator)
+ expression_dereference (&expr -> data.b2a.separator,
file, line);
if (expr -> data.b2a.buffer)
expression_dereference (&expr -> data.b2a.buffer,
@@ -3523,7 +3523,7 @@ int write_expression (file, expr, col, indent, firstp)
col, scol, 0);
col = token_print_indent (file, col, scol, "", " ",
",");
- col = write_expression (file, expr -> data.b2a.seperator,
+ col = write_expression (file, expr -> data.b2a.separator,
col, scol, 0);
col = token_print_indent (file, col, scol, "", " ",
",");
@@ -1694,12 +1694,12 @@ int evaluate_data_expression (result, packet, lease, client_state,
scope,
expr -> data.b2a.width);
- /* Evaluate the seperator string. */
+ /* Evaluate the separator string. */
memset (&data, 0, sizeof data);
s2 = evaluate_data_expression (&data, packet, lease,